@@ -35,9 +35,9 @@ typedef struct {
 	GObjectClass	base;
 } GODocControlClass;
 
-#define GO_DOC_CONTROL_CLASS(k)     (G_TYPE_CHECK_CLASS_CAST ((k),   GO_DOC_CONTROL_TYPE, GODocControlClass))
-#define IS_GO_DOC_CONTROL_CLASS(k)  (G_TYPE_CHECK_CLASS_TYPE ((k),   GO_DOC_CONTROL_TYPE))
-#define GO_DOC_CONTROL_GET_CLASS(o) (G_TYPE_INSTANCE_GET_CLASS ((o), GO_DOC_CONTROL_TYPE, GODocControlClass))
+#define GO_DOC_CONTROL_CLASS(k)     (G_TYPE_CHECK_CLASS_CAST ((k),   GO_TYPE_DOC_CONTROL, GODocControlClass))
+#define GO_IS_DOC_CONTROL_CLASS(k)  (G_TYPE_CHECK_CLASS_TYPE ((k),   GO_TYPE_DOC_CONTROL))
+#define GO_DOC_CONTROL_GET_CLASS(o) (G_TYPE_INSTANCE_GET_CLASS ((o), GO_TYPE_DOC_CONTROL, GODocControlClass))
 
 G_END_DECLS
 
