@@ -1,6 +1,6 @@
 /* vim: set sw=8: -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*
- * go-data-simple.c : 
+ * go-data-simple.c :
  *
  * Copyright (C) 2003-2005 Jody Goldberg (jody@gnome.org)
  *
@@ -21,7 +21,7 @@
 #include <goffice/goffice-config.h>
 #include "go-data-simple.h"
 #include "go-data-impl.h"
-#include <goffice/utils/go-format.h>
+#include <goffice/utils/go-glib-extras.h>
 #include <goffice/utils/go-locale.h>
 #include <goffice/math/go-math.h>
 
@@ -32,6 +32,16 @@
 #include <errno.h>
 #include <stdlib.h>
 
+static char *
+render_val (double val, GOFormat const *fmt)
+{
+	if (fmt)
+		return go_format_value (fmt, val);
+	else
+		return g_strdup_printf ("%g", val);
+}
+
+
 struct _GODataScalarVal {
 	GODataScalar	 base;
 	double		 val;
@@ -72,13 +82,14 @@ go_data_scalar_val_eq (GOData const *a, GOData const *b)
 }
 
 static char *
-go_data_scalar_val_as_str (GOData const *dat)
+go_data_scalar_val_serialize (GOData const *dat, gpointer user)
 {
+	/* FIXME: shouldn't use _get_str.  */
 	return g_strdup (go_data_scalar_get_str (GO_DATA_SCALAR (dat)));
 }
 
 static gboolean
-go_data_scalar_val_from_str (GOData *dat, char const *str)
+go_data_scalar_val_unserialize (GOData *dat, char const *str, gpointer user)
 {
 	GODataScalarVal *sval = (GODataScalarVal *)dat;
 	double tmp;
@@ -106,9 +117,10 @@ static char const *
 go_data_scalar_val_get_str (GODataScalar *dat)
 {
 	GODataScalarVal *sval = (GODataScalarVal *)dat;
+	GOFormat const *fmt = NULL;
 
 	if (sval->str == NULL)
-		sval->str = g_strdup_printf ("%g", sval->val);
+		sval->str = render_val (sval->val, fmt);
 	return sval->str;
 }
 
@@ -118,14 +130,14 @@ go_data_scalar_val_class_init (GObjectClass *gobject_klass)
 	GODataClass *godata_klass = (GODataClass *) gobject_klass;
 	GODataScalarClass *scalar_klass = (GODataScalarClass *) gobject_klass;
 
-	scalar_val_parent_klass = g_type_class_peek_parent (gobject_klass);
-	gobject_klass->finalize = go_data_scalar_val_finalize;
-	godata_klass->dup	= go_data_scalar_val_dup;
-	godata_klass->eq	= go_data_scalar_val_eq;
-	godata_klass->as_str	= go_data_scalar_val_as_str;
-	godata_klass->from_str	= go_data_scalar_val_from_str;
-	scalar_klass->get_value	= go_data_scalar_val_get_value;
-	scalar_klass->get_str	= go_data_scalar_val_get_str;
+	scalar_val_parent_klass   = g_type_class_peek_parent (gobject_klass);
+	gobject_klass->finalize   = go_data_scalar_val_finalize;
+	godata_klass->dup	  = go_data_scalar_val_dup;
+	godata_klass->eq	  = go_data_scalar_val_eq;
+	godata_klass->serialize	  = go_data_scalar_val_serialize;
+	godata_klass->unserialize = go_data_scalar_val_unserialize;
+	scalar_klass->get_value	  = go_data_scalar_val_get_value;
+	scalar_klass->get_str	  = go_data_scalar_val_get_str;
 }
 
 GSF_CLASS (GODataScalarVal, go_data_scalar_val,
@@ -182,14 +194,14 @@ go_data_scalar_str_eq (GOData const *a, GOData const *b)
 }
 
 static char *
-go_data_scalar_str_as_str (GOData const *dat)
+go_data_scalar_str_serialize (GOData const *dat, gpointer user)
 {
 	GODataScalarStr const *str = (GODataScalarStr const *)dat;
 	return g_strdup (str->str);
 }
 
 static gboolean
-go_data_scalar_str_from_str (GOData *dat, char const *string)
+go_data_scalar_str_unserialize (GOData *dat, char const *string, gpointer user)
 {
 	GODataScalarStr *str = (GODataScalarStr *)dat;
 
@@ -225,8 +237,8 @@ go_data_scalar_str_class_init (GObjectClass *gobject_klass)
 	gobject_klass->finalize	= go_data_scalar_str_finalize;
 	godata_klass->dup	= go_data_scalar_str_dup;
 	godata_klass->eq	= go_data_scalar_str_eq;
-	godata_klass->as_str	= go_data_scalar_str_as_str;
-	godata_klass->from_str	= go_data_scalar_str_from_str;
+	godata_klass->serialize	= go_data_scalar_str_serialize;
+	godata_klass->unserialize = go_data_scalar_str_unserialize;
 	scalar_klass->get_value	= go_data_scalar_str_get_value;
 	scalar_klass->get_str	= go_data_scalar_str_get_str;
 }
@@ -352,34 +364,36 @@ static char *
 go_data_vector_val_get_str (GODataVector *vec, unsigned i)
 {
 	GODataVectorVal const *val = (GODataVectorVal const *)vec;
+	GOFormat const *fmt = NULL;
+
 	g_return_val_if_fail (val != NULL && val->val != NULL && i < val->n, NULL);
-	return g_strdup_printf ("%g", val->val[i]);
+
+	return render_val (val->val[i], fmt);
 }
 
 static char *
-go_data_vector_val_as_str (GOData const *dat)
+go_data_vector_val_serialize (GOData const *dat, gpointer user)
 {
 	GODataVectorVal *vec = GO_DATA_VECTOR_VAL (dat);
+	GOFormat const *fmt = NULL;
 	GString *str;
-	char sep, sz[G_ASCII_DTOSTR_BUF_SIZE];
+	char sep;
 	unsigned i;
 
-	if (vec->n ==0)
-		return g_strdup ("");
-
 	sep = go_locale_get_col_sep ();
-	g_snprintf (sz, sizeof (sz), "%g", vec->val[0]);
-	str = g_string_new (sz);
-	for (i = 1; i < vec->n; i++) {
-		g_string_append_c (str, sep);
-		g_snprintf (sz, sizeof (sz), "%g", vec->val[i]);
-		g_string_append (str, sz);
+	str = g_string_new (NULL);
+
+	for (i = 0; i < vec->n; i++) {
+		char *s = render_val (vec->val[i], fmt);
+		if (i) g_string_append_c (str, sep);
+		g_string_append (str, s);
+		g_free (s);
 	}
 	return g_string_free (str, FALSE);
 }
 
 static gboolean
-go_data_vector_val_from_str (GOData *dat, char const *str)
+go_data_vector_val_unserialize (GOData *dat, char const *str, gpointer user)
 {
 	GODataVectorVal *vec = GO_DATA_VECTOR_VAL (dat);
 	char sep, *end = (char*) str;
@@ -435,8 +449,8 @@ go_data_vector_val_class_init (GObjectClass *gobject_klass)
 	gobject_klass->finalize = go_data_vector_val_finalize;
 	godata_klass->dup	= go_data_vector_val_dup;
 	godata_klass->eq	= go_data_vector_val_eq;
-	godata_klass->as_str	= go_data_vector_val_as_str;
-	godata_klass->from_str	= go_data_vector_val_from_str;
+	godata_klass->serialize	= go_data_vector_val_serialize;
+	godata_klass->unserialize	= go_data_vector_val_unserialize;
 	vector_klass->load_len    = go_data_vector_val_load_len;
 	vector_klass->load_values = go_data_vector_val_load_values;
 	vector_klass->get_value   = go_data_vector_val_get_value;
@@ -463,11 +477,11 @@ struct _GODataVectorStr {
 	GODataVector	 base;
 	char const * const *str;
 	int n;
-	GDestroyNotify notify;   
+	GDestroyNotify notify;
 
 	GOTranslateFunc translate_func;
 	gpointer        translate_data;
-	GDestroyNotify  translate_notify;   
+	GDestroyNotify  translate_notify;
 };
 typedef GODataVectorClass GODataVectorStrClass;
 
@@ -527,32 +541,23 @@ go_data_vector_str_eq (GOData const *a, GOData const *b)
 }
 
 static char *
-go_data_vector_str_as_str (GOData const *dat)
+go_data_vector_str_serialize (GOData const *dat, gpointer user)
 {
 	GODataVectorStr *vec = GO_DATA_VECTOR_STR (dat);
-	GString *str;
-	char sep;
+	GString *str= g_string_new (NULL);
+	char sep = go_locale_get_col_sep ();
 	int i;
 
-	sep = go_locale_get_col_sep ();
-	if (vec->n ==0)
-		return g_strdup ("");
-
-	str = g_string_new ("");
-	g_string_append_c (str, '\"');
-	g_string_append (str, vec->str[0]);
-	g_string_append_c (str, '\"');
-	for (i = 1; i < vec->n; i++) {
-		g_string_append_c (str, sep);
-		g_string_append_c (str, '\"');
-		g_string_append (str, vec->str[i]);
-		g_string_append_c (str, '\"');
+	for (i = 0; i < vec->n; i++) {
+		if (i) g_string_append_c (str, sep);
+		go_strescape (str, vec->str[i]);
 	}
+
 	return g_string_free (str, FALSE);
 }
 
 static gboolean
-go_data_vector_str_from_str (GOData *dat, char const *str)
+go_data_vector_str_unserialize (GOData *dat, char const *str, gpointer user)
 {
 	GODataVectorStr *vec = GO_DATA_VECTOR_STR (dat);
 	char sep, *cur = (char*) str, *end, *val;
@@ -612,7 +617,7 @@ go_data_vector_str_from_str (GOData *dat, char const *str)
 				/* string containg quotes are not allowed */
 				g_array_free (values, TRUE);
 				return FALSE;
-			}					
+			}
 			cur = end + 1;
 		}
 	}
@@ -695,8 +700,8 @@ go_data_vector_str_class_init (GObjectClass *gobject_klass)
 	gobject_klass->finalize	= go_data_vector_str_finalize;
 	godata_klass->dup	= go_data_vector_str_dup;
 	godata_klass->eq	= go_data_vector_str_eq;
-	godata_klass->as_str	= go_data_vector_str_as_str;
-	godata_klass->from_str	= go_data_vector_str_from_str;
+	godata_klass->serialize	= go_data_vector_str_serialize;
+	godata_klass->unserialize	= go_data_vector_str_unserialize;
 	vector_klass->load_len    = go_data_vector_str_load_len;
 	vector_klass->load_values = go_data_vector_str_load_values;
 	vector_klass->get_value   = go_data_vector_str_get_value;
@@ -734,9 +739,9 @@ go_data_vector_str_new (char const * const *str, unsigned n, GDestroyNotify noti
  * @vector: a #GODataVectorStr
  * @func: a #GOTranslateFunc
  * @data: data to be passed to @func and @notify
- * @notify: a #GODestroyNotify function to be called when @vec is 
+ * @notify: a #GDestroyNotify function to be called when @vec is
  *   destroyed or when the translation function is changed
- * 
+ *
  * Sets a function to be used for translating elements of @vec
  **/
 void
@@ -756,7 +761,7 @@ go_data_vector_str_set_translate_func (GODataVectorStr	*vec,
 }
 
 static char const *
-dgettext_swapped (char const *msgid, 
+dgettext_swapped (char const *msgid,
 		  char const *domainname)
 {
 	return dgettext (domainname, msgid);
@@ -766,23 +771,23 @@ dgettext_swapped (char const *msgid,
  * go_data_vector_str_set_translation_domain:
  * @vector: a #GODataVectorStr
  * @domain: the translation domain to use for dgettext() calls
- * 
- * Sets the translation domain and uses dgettext() for translating the 
+ *
+ * Sets the translation domain and uses dgettext() for translating the
  * elements of @vec.
  * Note that libgoffice expects all strings to be encoded in UTF-8, therefore
  * the translation domain must have its codeset set to UTF-8, see
- * bind_textdomain_codeset() in the gettext() documentation. 
+ * bind_textdomain_codeset() in the gettext() documentation.
  *
- * If you're not using gettext() for localization, see 
+ * If you're not using gettext() for localization, see
  * go_data_vector_str_set_translate_func().
  **/
-void 
+void
 go_data_vector_str_set_translation_domain (GODataVectorStr *vec,
 					   char const      *domain)
 {
 	g_return_if_fail (GO_DATA_VECTOR_STR (vec) != NULL);
 
-	go_data_vector_str_set_translate_func (vec, 
+	go_data_vector_str_set_translate_func (vec,
 		(GOTranslateFunc)dgettext_swapped, g_strdup (domain), g_free);
 }
 /*****************************************************************************/
@@ -874,45 +879,38 @@ static char *
 go_data_matrix_val_get_str (GODataMatrix *mat, unsigned i, unsigned j)
 {
 	GODataMatrixVal const *val = (GODataMatrixVal const *)mat;
+	GOFormat const *fmt = NULL;
 
-	return g_strdup_printf ("%g", val->val[i * val->size.columns + j]);
+	return render_val (val->val[i * val->size.columns + j], fmt);
 }
 
 static char *
-go_data_matrix_val_as_str (GOData const *dat)
+go_data_matrix_val_serialize (GOData const *dat, gpointer user)
 {
 	GODataMatrixVal *mat = GO_DATA_MATRIX_VAL (dat);
+	GOFormat const *fmt = NULL;
 	GString *str;
-	char row_sep, col_sep, sz[G_ASCII_DTOSTR_BUF_SIZE];
-	int i, j;
+	int c, r;
+	char col_sep = go_locale_get_col_sep ();
+	char row_sep = go_locale_get_row_sep ();
 
-	if (mat->size.rows == 0 || mat->size.columns == 0)
-		return g_strdup ("");
-
-	col_sep = go_locale_get_col_sep ();
-	row_sep = go_locale_get_row_sep ();
-	g_snprintf (sz, sizeof (sz), "%g", mat->val[0]);
-	str = g_string_new (sz);
-	for (j = 1; j < mat->size.columns; j++) {
-		g_string_append_c (str, col_sep);
-		g_snprintf (sz, sizeof (sz), "%g", mat->val[j]);
-		g_string_append (str, sz);
-	}
-	for (i = 1; i < mat->size.rows; i++) {
-		g_string_append_c (str, row_sep);
-		g_snprintf (sz, sizeof (sz), "%g", mat->val[i * mat->size.columns]);
-		g_string_append (str, sz);
-		for (j = 1; j < mat->size.columns; j++) {
-			g_string_append_c (str, col_sep);
-			g_snprintf (sz, sizeof (sz), "%g", mat->val[i * mat->size.columns + j]);
-			g_string_append (str, sz);
+	str = g_string_new (NULL);
+	for (r = 0; r < mat->size.rows; r++) {
+		if (r) g_string_append_c (str, row_sep);
+		for (c = 0; c < mat->size.columns; c++) {
+			double val = mat->val[r * mat->size.columns + c];
+			char *s = render_val (val, fmt);
+			if (c) g_string_append_c (str, col_sep);
+			g_string_append (str, s);
+			g_free (s);
 		}
 	}
+
 	return g_string_free (str, FALSE);
 }
 
 static gboolean
-go_data_matrix_val_from_str (GOData *dat, char const *str)
+go_data_matrix_val_unserialize (GOData *dat, char const *str, gpointer user)
 {
 	GODataMatrixVal *mat = GO_DATA_MATRIX_VAL (dat);
 	char row_sep, col_sep, *end = (char*) str;
@@ -986,9 +984,9 @@ go_data_matrix_val_class_init (GObjectClass *gobject_klass)
 	gobject_klass->finalize = go_data_matrix_val_finalize;
 	godata_klass->dup	= go_data_matrix_val_dup;
 	godata_klass->eq	= go_data_matrix_val_eq;
-	godata_klass->as_str	= go_data_matrix_val_as_str;
-	godata_klass->from_str	= go_data_matrix_val_from_str;
-	matrix_klass->load_size    = go_data_matrix_val_load_size;
+	godata_klass->serialize	= go_data_matrix_val_serialize;
+	godata_klass->unserialize = go_data_matrix_val_unserialize;
+	matrix_klass->load_size   = go_data_matrix_val_load_size;
 	matrix_klass->load_values = go_data_matrix_val_load_values;
 	matrix_klass->get_value   = go_data_matrix_val_get_value;
 	matrix_klass->get_str     = go_data_matrix_val_get_str;
