@@ -95,7 +95,7 @@ GSF_CLASS_ABSTRACT (GOData, go_data,
 		    G_TYPE_OBJECT)
 
 /**
- * go_data_dup : 
+ * go_data_dup :
  * @src : #GOData
  *
  * Returns: A deep copy of @src.
@@ -707,6 +707,10 @@ go_data_vector_get_str (GODataVector *vec, unsigned i)
 	char *res;
 
 	g_return_val_if_fail (klass != NULL, g_strdup (""));
+	if (! (vec->base.flags & GO_DATA_VECTOR_LEN_CACHED)) {
+		(*klass->load_len) (vec);
+		g_return_val_if_fail (vec->base.flags & GO_DATA_VECTOR_LEN_CACHED, g_strdup (""));
+	}
 	g_return_val_if_fail ((int)i < vec->len, g_strdup (""));
 
 	res = (*klass->get_str) (vec, i);
@@ -883,6 +887,10 @@ go_data_matrix_get_str (GODataMatrix *mat, unsigned i, unsigned j)
 	char *res;
 
 	g_return_val_if_fail (klass != NULL, NULL);
+	if (! (mat->base.flags & GO_DATA_MATRIX_SIZE_CACHED)) {
+		(*klass->load_size) (mat);
+		g_return_val_if_fail (mat->base.flags & GO_DATA_MATRIX_SIZE_CACHED, g_strdup (""));
+	}
 	g_return_val_if_fail (((int)i < mat->size.rows) && ((int)j < mat->size.columns), g_strdup (""));
 
 	res = (*klass->get_str) (mat, i, j);
