@@ -1,6 +1,6 @@
 /* vim: set sw=8: -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*
- * gog-equation.h : 
+ * gog-equation.h :
  *
  * Copyright (C) 2008 Emmanuel Pacaud <emmanuel@gnome.org>
  *
@@ -22,8 +22,7 @@
 #ifndef GOG_EQUATION_H
 #define GOG_EQUATION_H
 
-#include <goffice/graph/goffice-graph.h>
-#include <glib-object.h>
+#include <goffice/goffice.h>
 
 G_BEGIN_DECLS
 
