@@ -23,14 +23,14 @@
 #include <goffice/graph/gog-plot-engine.h>
 #include <goffice/graph/gog-plot-impl.h>
 #include <goffice/graph/gog-theme.h>
-#include <goffice/graph/gog-reg-curve.h>
+#include <goffice/graph/gog-trend-line.h>
 #include <goffice/graph/gog-chart.h>
 #include <goffice/app/go-plugin-service.h>
 #include <goffice/app/go-plugin-service-impl.h>
 #include <goffice/app/error-info.h>
 #include <goffice/utils/go-libxml-extras.h>
 
-#include <glib/gi18n.h>
+#include <glib/gi18n-lib.h>
 #include <gsf/gsf-impl-utils.h>
 #include <string.h>
 
@@ -39,14 +39,14 @@ static GSList *refd_plugins;
 /***************************************************************************/
 /* Support plot engines in plugins */
 
-#define GOG_PLOT_ENGINE_SERVICE_TYPE  (gog_plot_engine_service_get_type ())
-#define GOG_PLOT_ENGINE_SERVICE(o)    (G_TYPE_CHECK_INSTANCE_CAST ((o), GOG_PLOT_ENGINE_SERVICE_TYPE, GogPlotEngineService))
-#define IS_GOG_PLOT_ENGINE_SERVICE(o) (G_TYPE_CHECK_INSTANCE_TYPE ((o), GOG_PLOT_ENGINE_SERVICE_TYPE))
+#define GOG_TYPE_PLOT_ENGINE_SERVICE  (gog_plot_engine_service_get_type ())
+#define GOG_PLOT_ENGINE_SERVICE(o)    (G_TYPE_CHECK_INSTANCE_CAST ((o), GOG_TYPE_PLOT_ENGINE_SERVICE, GogPlotEngineService))
+#define GOG_IS_PLOT_ENGINE_SERVICE(o) (G_TYPE_CHECK_INSTANCE_TYPE ((o), GOG_TYPE_PLOT_ENGINE_SERVICE))
 
 static GType gog_plot_engine_service_get_type (void);
 
-typedef PluginServiceGObjectLoader	GogPlotEngineService;
-typedef PluginServiceGObjectLoaderClass GogPlotEngineServiceClass;
+typedef GOPluginServiceGObjectLoader	GogPlotEngineService;
+typedef GOPluginServiceGObjectLoaderClass GogPlotEngineServiceClass;
 
 static GHashTable *pending_engines = NULL;
 
@@ -57,9 +57,9 @@ gog_plot_engine_service_get_description (GOPluginService *service)
 }
 
 static void
-gog_plot_engine_service_class_init (PluginServiceGObjectLoaderClass *gobj_loader_class)
+gog_plot_engine_service_class_init (GOPluginServiceGObjectLoaderClass *gobj_loader_class)
 {
-	GOPluginServiceClass *ps_class = GPS_CLASS (gobj_loader_class);
+	GOPluginServiceClass *ps_class = GO_PLUGIN_SERVICE_CLASS (gobj_loader_class);
 
 	ps_class->get_description = gog_plot_engine_service_get_description;
 
@@ -69,7 +69,7 @@ gog_plot_engine_service_class_init (PluginServiceGObjectLoaderClass *gobj_loader
 
 GSF_CLASS (GogPlotEngineService, gog_plot_engine_service,
            gog_plot_engine_service_class_init, NULL,
-           GO_PLUGIN_SERVICE_GOBJECT_LOADER_TYPE)
+           GO_TYPE_PLUGIN_SERVICE_GOBJECT_LOADER)
 
 GogPlot *
 gog_plot_new_by_name (char const *id)
@@ -77,7 +77,7 @@ gog_plot_new_by_name (char const *id)
 	GType type = g_type_from_name (id);
 
 	if (type == 0) {
-		ErrorInfo *err = NULL;
+		GOErrorInfo *err = NULL;
 		GOPluginService *service =
 			pending_engines
 			? g_hash_table_lookup (pending_engines, id)
@@ -89,12 +89,12 @@ gog_plot_new_by_name (char const *id)
 
 		g_return_val_if_fail (!service->is_loaded, NULL);
 
-		plugin_service_load (service, &err);
+		go_plugin_service_load (service, &err);
 		type = g_type_from_name (id);
 
 		if (err != NULL) {
-			error_info_print (err);
-			error_info_free	(err);
+			go_error_info_print (err);
+			go_error_info_free	(err);
 		}
 
 		g_return_val_if_fail (type != 0, NULL);
@@ -102,7 +102,7 @@ gog_plot_new_by_name (char const *id)
 		/*
 		 * The plugin defined a gtype so it must not be unloaded.
 		 */
-		plugin = plugin_service_get_plugin (service);
+		plugin = go_plugin_service_get_plugin (service);
 		refd_plugins = g_slist_prepend (refd_plugins, plugin);
 		g_object_ref (plugin);
 		go_plugin_use_ref (plugin);
@@ -114,20 +114,20 @@ gog_plot_new_by_name (char const *id)
 /***************************************************************************/
 /* Use a plugin service to define where to find plot types */
 
-#define GOG_PLOT_TYPE_SERVICE_TYPE  (gog_plot_type_service_get_type ())
-#define GOG_PLOT_TYPE_SERVICE(o)    (G_TYPE_CHECK_INSTANCE_CAST ((o), GOG_PLOT_TYPE_SERVICE_TYPE, GogPlotTypeService))
-#define IS_GOG_PLOT_TYPE_SERVICE(o) (G_TYPE_CHECK_INSTANCE_TYPE ((o), GOG_PLOT_TYPE_SERVICE_TYPE))
+#define GOG_TYPE_PLOT_TYPE_SERVICE  (gog_plot_type_service_get_type ())
+#define GOG_PLOT_TYPE_SERVICE(o)    (G_TYPE_CHECK_INSTANCE_CAST ((o), GOG_TYPE_PLOT_TYPE_SERVICE, GogPlotTypeService))
+#define GOG_IS_PLOT_TYPE_SERVICE(o) (G_TYPE_CHECK_INSTANCE_TYPE ((o), GOG_TYPE_PLOT_TYPE_SERVICE))
 
 GType gog_plot_type_service_get_type (void);
 
 typedef struct {
-	PluginServiceSimple	base;
+	GOPluginServiceSimple	base;
 
-	GSList	*families, *types;
+	GSList	*families, *types, *paths;
 } GogPlotTypeService;
 
 typedef struct{
-	PluginServiceSimpleClass	base;
+	GOPluginServiceSimpleClass	base;
 } GogPlotTypeServiceClass;
 
 static GHashTable *pending_plot_type_files = NULL;
@@ -154,7 +154,7 @@ cb_pending_plot_types_load (char const *path,
 		if (!xmlIsBlankNode (ptr) && ptr->name && !strcmp (ptr->name, "Family")) {
 			name	    = xmlGetProp (ptr, "_name");
 			image_file  = xmlGetProp (ptr, "sample_image_file");
-			if (!xml_node_get_int (ptr, "priority", &priority))
+			if (!go_xml_node_get_int (ptr, "priority", &priority))
 				priority = 0;
 			axis_set_str = xmlGetProp (ptr, "axis_set");
 			axis_set = gog_axis_set_from_str (axis_set_str);
@@ -183,8 +183,8 @@ cb_pending_plot_types_load (char const *path,
 			image_file  = xmlGetProp (ptr, "sample_image_file");
 			description = xmlGetProp (ptr, "_description");
 			engine	    = xmlGetProp (ptr, "engine");
-			if (xml_node_get_int (ptr, "col", &col) &&
-			    xml_node_get_int (ptr, "row", &row)) {
+			if (go_xml_node_get_int (ptr, "col", &col) &&
+			    go_xml_node_get_int (ptr, "row", &row)) {
 				type = gog_plot_type_register (family, col, row,
 					name, image_file, description, engine);
 				if (type != NULL) {
@@ -200,7 +200,7 @@ cb_pending_plot_types_load (char const *path,
 							}
 
 							if (type->properties == NULL)
-								type->properties = 
+								type->properties =
 									g_hash_table_new_full (g_str_hash, g_str_equal,
 											       xmlFree, xmlFree);
 							g_hash_table_replace (type->properties,
@@ -230,27 +230,65 @@ pending_plot_types_load (void)
 }
 
 static void
-gog_plot_type_service_read_xml (GOPluginService *service, xmlNode *tree, ErrorInfo **ret_error)
+gog_plot_type_service_read_xml (GOPluginService *service, xmlNode *tree, GOErrorInfo **ret_error)
 {
 	char    *path;
 	xmlNode *ptr;
+	GSList *paths = NULL;
 
 	for (ptr = tree->xmlChildrenNode; ptr != NULL; ptr = ptr->next)
 		if (0 == xmlStrcmp (ptr->name, "file") &&
 		    NULL != (path = xmlNodeGetContent (ptr))) {
 			if (!g_path_is_absolute (path)) {
 				char const *dir = go_plugin_get_dir_name (
-					plugin_service_get_plugin (service));
+					go_plugin_service_get_plugin (service));
 				char *tmp = g_build_filename (dir, path, NULL);
 				g_free (path);
 				path = tmp;
 			}
-			if (pending_plot_type_files == NULL)
-				pending_plot_type_files = g_hash_table_new_full (
-					g_str_hash, g_str_equal, g_free, g_object_unref);
-			g_object_ref (service);
-			g_hash_table_replace (pending_plot_type_files, path, service);
+			paths = g_slist_append (paths, path);
 		}
+	GOG_PLOT_TYPE_SERVICE (service)->paths = paths;
+}
+
+static void
+gog_plot_type_service_activate (GOPluginService *service, GOErrorInfo **ret_error)
+{
+	GSList *l = GOG_PLOT_TYPE_SERVICE (service)->paths;
+	if (l && pending_plot_type_files == NULL)
+		pending_plot_type_files = g_hash_table_new_full (
+			g_str_hash, g_str_equal, g_free, g_object_unref);
+	while (l) {
+		g_object_ref (service);
+		g_hash_table_replace (pending_plot_type_files, g_strdup (l->data), service);
+		l = l->next;
+	}
+	service->is_active = TRUE;
+}
+
+static void
+gog_plot_type_service_deactivate (GOPluginService *service, GOErrorInfo **ret_error)
+{
+	GogPlotTypeService *plot_service = GOG_PLOT_TYPE_SERVICE (service);
+	GSList *l = plot_service->families;
+	while (l) {
+		gog_plot_family_unregister ((GogPlotFamily *) l->data);
+		l = l->next;
+	}
+	g_slist_free (plot_service->families);
+	plot_service->families = NULL;
+
+	g_slist_free (plot_service->types);
+	plot_service->types = NULL;
+
+	if (pending_plot_type_files) {
+		l = plot_service->paths;
+		while (l) {
+		    g_hash_table_remove (pending_plot_type_files, l->data);
+		    l = l->next;
+	    }
+	}
+	service->is_active = FALSE;
 }
 
 static char *
@@ -259,22 +297,32 @@ gog_plot_type_service_get_description (GOPluginService *service)
 	return g_strdup (_("Plot Type"));
 }
 
+static void gog_plot_family_free (GogPlotFamily *family);
+static void gog_plot_type_free (GogPlotType *type);
+
 static void
 gog_plot_type_service_finalize (GObject *obj)
 {
 	GogPlotTypeService *service = GOG_PLOT_TYPE_SERVICE (obj);
 	GSList *ptr;
 
-	for (ptr = service->families ; ptr != NULL ; ptr = ptr->next) {
-	}
+	for (ptr = service->families ; ptr != NULL ; ptr = ptr->next)
+		gog_plot_family_free ((GogPlotFamily *) ptr->data);
 	g_slist_free (service->families);
 	service->families = NULL;
 
-	for (ptr = service->types ; ptr != NULL ; ptr = ptr->next) {
-	}
+	/* plot types are freed by gog_plot_family_free, so no need to
+	free anything but the list here */
 	g_slist_free (service->types);
 	service->types = NULL;
 
+	for (ptr = service->paths ; ptr != NULL ; ptr = ptr->next) {
+		g_hash_table_remove (pending_engines, ptr->data);
+		g_free (ptr->data);
+	}
+	g_slist_free (service->paths);
+	service->paths = NULL;
+
 	(plot_type_parent_klass->finalize) (obj);
 }
 
@@ -285,53 +333,58 @@ gog_plot_type_service_init (GObject *obj)
 
 	service->families = NULL;
 	service->types = NULL;
+	service->paths = NULL;
 }
 
 static void
 gog_plot_type_service_class_init (GObjectClass *gobject_klass)
 {
-	GOPluginServiceClass *ps_class = GPS_CLASS (gobject_klass);
+	GOPluginServiceClass *ps_class = GO_PLUGIN_SERVICE_CLASS (gobject_klass);
 
 	plot_type_parent_klass = g_type_class_peek_parent (gobject_klass);
 	gobject_klass->finalize		= gog_plot_type_service_finalize;
 	ps_class->read_xml		= gog_plot_type_service_read_xml;
 	ps_class->get_description	= gog_plot_type_service_get_description;
+	ps_class->activate		= gog_plot_type_service_activate;
+	ps_class->deactivate		= gog_plot_type_service_deactivate;
 }
 
 GSF_CLASS (GogPlotTypeService, gog_plot_type_service,
            gog_plot_type_service_class_init, gog_plot_type_service_init,
-           GO_PLUGIN_SERVICE_SIMPLE_TYPE)
+           GO_TYPE_PLUGIN_SERVICE_SIMPLE)
 
 /***************************************************************************/
 /* Use a plugin service to define themes */
 
-#define GOG_THEME_SERVICE_TYPE  (gog_theme_service_get_type ())
-#define GOG_THEME_SERVICE(o)    (G_TYPE_CHECK_INSTANCE_CAST ((o), GOG_THEME_SERVICE_TYPE, GogThemeService))
-#define IS_GOG_THEME_SERVICE(o) (G_TYPE_CHECK_INSTANCE_TYPE ((o), GOG_THEME_SERVICE_TYPE))
+#define GOG_TYPE_THEME_SERVICE  (gog_theme_service_get_type ())
+#define GOG_THEME_SERVICE(o)    (G_TYPE_CHECK_INSTANCE_CAST ((o), GOG_TYPE_THEME_SERVICE, GogThemeService))
+#define GOG_IS_THEME_SERVICE(o) (G_TYPE_CHECK_INSTANCE_TYPE ((o), GOG_TYPE_THEME_SERVICE))
 
 GType gog_theme_service_get_type (void);
 
-typedef PluginServiceSimple GogThemeService;
-typedef PluginServiceSimpleClass GogThemeServiceClass;
+typedef GOPluginServiceSimple GogThemeService;
+typedef GOPluginServiceSimpleClass GogThemeServiceClass;
 
 static void
-gog_theme_service_read_xml (GOPluginService *service, xmlNode *tree, ErrorInfo **ret_error)
+gog_theme_service_read_xml (GOPluginService *service, xmlNode *tree, GOErrorInfo **ret_error)
 {
-	char    *path;
+	GogTheme *theme;
 	xmlNode *ptr;
+	char    *path;
 
 	for (ptr = tree->xmlChildrenNode; ptr != NULL; ptr = ptr->next)
 		if (0 == xmlStrcmp (ptr->name, "file") &&
 		    NULL != (path = xmlNodeGetContent (ptr))) {
 			if (!g_path_is_absolute (path)) {
 				char const *dir = go_plugin_get_dir_name (
-					plugin_service_get_plugin (service));
+					go_plugin_service_get_plugin (service));
 				char *tmp = g_build_filename (dir, path, NULL);
 				g_free (path);
 				path = tmp;
 			}
-			gog_theme_register_file (
-				plugin_service_get_description (service), path);
+			theme = gog_theme_new_from_file (go_plugin_service_get_description (service),
+							 path);
+			gog_theme_registry_add (theme, FALSE);
 		}
 }
 
@@ -350,53 +403,53 @@ gog_theme_service_class_init (GOPluginServiceClass *ps_class)
 
 GSF_CLASS (GogThemeService, gog_theme_service,
            gog_theme_service_class_init, NULL,
-           GO_PLUGIN_SERVICE_SIMPLE_TYPE)
+           GO_TYPE_PLUGIN_SERVICE_SIMPLE)
 
 /***************************************************************************/
 /* Support regression curves engines in plugins */
 
-#define GOG_REG_CURVE_ENGINE_SERVICE_TYPE  (gog_reg_curve_engine_service_get_type ())
-#define GOG_REG_CURVE_ENGINE_SERVICE(o)    (G_TYPE_CHECK_INSTANCE_CAST ((o), GOG_REG_CURVE_ENGINE_SERVICE_TYPE, GogRegCurveEngineService))
-#define IS_GOG_REG_CURVE_ENGINE_SERVICE(o) (G_TYPE_CHECK_INSTANCE_TYPE ((o), GOG_REG_CURVE_ENGINE_SERVICE_TYPE))
+#define GOG_TYPE_TREND_LINE_ENGINE_SERVICE  (gog_trend_line_engine_service_get_type ())
+#define GOG_TREND_LINE_ENGINE_SERVICE(o)    (G_TYPE_CHECK_INSTANCE_CAST ((o), GOG_TYPE_TREND_LINE_ENGINE_SERVICE, GogTrendLineEngineService))
+#define GOG_IS_TREND_LINE_ENGINE_SERVICE(o) (G_TYPE_CHECK_INSTANCE_TYPE ((o), GOG_TYPE_TREND_LINE_ENGINE_SERVICE))
 
-static GType gog_reg_curve_engine_service_get_type (void);
+static GType gog_trend_line_engine_service_get_type (void);
 
-typedef PluginServiceGObjectLoader	GogRegCurveEngineService;
-typedef PluginServiceGObjectLoaderClass GogRegCurveEngineServiceClass;
+typedef GOPluginServiceGObjectLoader	GogTrendLineEngineService;
+typedef GOPluginServiceGObjectLoaderClass GogTrendLineEngineServiceClass;
 
-static GHashTable *pending_reg_curves_engines = NULL;
+static GHashTable *pending_trend_lines_engines = NULL;
 
 static char *
-gog_reg_curve_engine_service_get_description (GOPluginService *service)
+gog_trend_line_engine_service_get_description (GOPluginService *service)
 {
 	return g_strdup (_("Regression Curve Engine"));
 }
 
 static void
-gog_reg_curve_engine_service_class_init (PluginServiceGObjectLoaderClass *gobj_loader_class)
+gog_trend_line_engine_service_class_init (GOPluginServiceGObjectLoaderClass *gobj_loader_class)
 {
-	GOPluginServiceClass *ps_class = GPS_CLASS (gobj_loader_class);
+	GOPluginServiceClass *ps_class = GO_PLUGIN_SERVICE_CLASS (gobj_loader_class);
 
-	ps_class->get_description = gog_reg_curve_engine_service_get_description;
+	ps_class->get_description = gog_trend_line_engine_service_get_description;
 
 	gobj_loader_class->pending =
-		pending_reg_curves_engines = g_hash_table_new (g_str_hash, g_str_equal);
+		pending_trend_lines_engines = g_hash_table_new (g_str_hash, g_str_equal);
 }
 
-GSF_CLASS (GogRegCurveEngineService, gog_reg_curve_engine_service,
-           gog_reg_curve_engine_service_class_init, NULL,
-           GO_PLUGIN_SERVICE_GOBJECT_LOADER_TYPE)
+GSF_CLASS (GogTrendLineEngineService, gog_trend_line_engine_service,
+           gog_trend_line_engine_service_class_init, NULL,
+           GO_TYPE_PLUGIN_SERVICE_GOBJECT_LOADER)
 
-GogRegCurve *
-gog_reg_curve_new_by_name (char const *id)
+GogTrendLine *
+gog_trend_line_new_by_name (char const *id)
 {
 	GType type = g_type_from_name (id);
 
 	if (type == 0) {
-		ErrorInfo *err = NULL;
+		GOErrorInfo *err = NULL;
 		GOPluginService *service =
-			pending_reg_curves_engines
-			? g_hash_table_lookup (pending_reg_curves_engines, id)
+			pending_trend_lines_engines
+			? g_hash_table_lookup (pending_trend_lines_engines, id)
 			: NULL;
 		GOPlugin *plugin;
 
@@ -405,12 +458,12 @@ gog_reg_curve_new_by_name (char const *id)
 
 		g_return_val_if_fail (!service->is_loaded, NULL);
 
-		plugin_service_load (service, &err);
+		go_plugin_service_load (service, &err);
 		type = g_type_from_name (id);
 
 		if (err != NULL) {
-			error_info_print (err);
-			error_info_free	(err);
+			go_error_info_print (err);
+			go_error_info_free	(err);
 		}
 
 		g_return_val_if_fail (type != 0, NULL);
@@ -418,7 +471,7 @@ gog_reg_curve_new_by_name (char const *id)
 		/*
 		 * The plugin defined a gtype so it must not be unloaded.
 		 */
-		plugin = plugin_service_get_plugin (service);
+		plugin = go_plugin_service_get_plugin (service);
 		refd_plugins = g_slist_prepend (refd_plugins, plugin);
 		g_object_ref (plugin);
 		go_plugin_use_ref (plugin);
@@ -429,41 +482,41 @@ gog_reg_curve_new_by_name (char const *id)
 /***************************************************************************/
 /* Use a plugin service to define regression curves types */
 
-#define GOG_REG_CURVE_SERVICE_TYPE		(gog_reg_curve_service_get_type ())
-#define GOG_REG_CURVE_SERVICE(o)		(G_TYPE_CHECK_INSTANCE_CAST ((o), GOG_REG_CURVE_SERVICE_TYPE, GogRegCurveService))
-#define IS_GOG_REG_CURVE_SERVICE(o)	(G_TYPE_CHECK_INSTANCE_TYPE ((o), GOG_REG_CURVE_SERVICE_TYPE))
+#define GOG_TYPE_TREND_LINE_SERVICE		(gog_trend_line_service_get_type ())
+#define GOG_TREND_LINE_SERVICE(o)		(G_TYPE_CHECK_INSTANCE_CAST ((o), GOG_TYPE_TREND_LINE_SERVICE, GogTrendLineService))
+#define GOG_IS_TREND_LINE_SERVICE(o)	(G_TYPE_CHECK_INSTANCE_TYPE ((o), GOG_TYPE_TREND_LINE_SERVICE))
 
-GType gog_reg_curve_service_get_type (void);
+GType gog_trend_line_service_get_type (void);
 
 typedef struct {
-	PluginServiceSimple	base;
+	GOPluginServiceSimple	base;
 
-	GSList	*types;
-} GogRegCurveService;
-typedef PluginServiceSimpleClass GogRegCurveServiceClass;
+	GSList	*types, *paths;
+} GogTrendLineService;
+typedef GOPluginServiceSimpleClass GogTrendLineServiceClass;
 
-static GHashTable *pending_reg_curve_type_files = NULL;
-static GHashTable *reg_curves_types = NULL;
+static GHashTable *pending_trend_line_type_files = NULL;
+static GHashTable *trend_line_types = NULL;
 
 static void
-cb_pending_reg_curve_types_load (char const *path,
-			    GogRegCurveService *service,
+cb_pending_trend_line_types_load (char const *path,
+			    GogTrendLineService *service,
 			    G_GNUC_UNUSED gpointer ignored)
 {
 	xmlNode *ptr, *prop;
 	xmlDoc *doc = go_xml_parse_file (path);
-	GogRegCurveType *type;
+	GogTrendLineType *type;
 
 	g_return_if_fail (doc != NULL && doc->xmlRootNode != NULL);
 
 	for (ptr = doc->xmlRootNode->xmlChildrenNode; ptr ; ptr = ptr->next)
 		if (!xmlIsBlankNode (ptr) && ptr->name && !strcmp (ptr->name, "Type")) {
-			type = g_new0 (GogRegCurveType, 1);
+			type = g_new0 (GogTrendLineType, 1);
 			type->name = xmlGetProp (ptr, "_name");
 			type->description = xmlGetProp (ptr, "_description");
 			type->engine = xmlGetProp (ptr, "engine");
 			service->types = g_slist_prepend (service->types, type);
-			g_hash_table_insert (reg_curves_types, type->name, type);
+			g_hash_table_insert (trend_line_types, type->name, type);
 			for (prop = ptr->xmlChildrenNode ; prop != NULL ; prop = prop->next)
 				if (!xmlIsBlankNode (prop) &&
 					prop->name && !strcmp (prop->name, "property")) {
@@ -486,80 +539,139 @@ cb_pending_reg_curve_types_load (char const *path,
 }
 
 static void
-pending_reg_curves_types_load (void)
+pending_trend_line_types_load (void)
 {
-	if (pending_reg_curve_type_files != NULL) {
-		GHashTable *tmp = pending_reg_curve_type_files;
-		pending_reg_curve_type_files = NULL;
+	if (pending_trend_line_type_files != NULL) {
+		GHashTable *tmp = pending_trend_line_type_files;
+		pending_trend_line_type_files = NULL;
 		g_hash_table_foreach (tmp,
-			(GHFunc) cb_pending_reg_curve_types_load, NULL);
+			(GHFunc) cb_pending_trend_line_types_load, NULL);
 		g_hash_table_destroy (tmp);
 	}
 }
 
 static void
-gog_reg_curve_service_read_xml (GOPluginService *service, xmlNode *tree, ErrorInfo **ret_error)
+gog_trend_line_service_read_xml (GOPluginService *service, xmlNode *tree, GOErrorInfo **ret_error)
 {
 	char    *path;
 	xmlNode *ptr;
+	GSList *paths = NULL;
 
 	for (ptr = tree->xmlChildrenNode; ptr != NULL; ptr = ptr->next)
 		if (0 == xmlStrcmp (ptr->name, "file") &&
 		    NULL != (path = xmlNodeGetContent (ptr))) {
 			if (!g_path_is_absolute (path)) {
 				char const *dir = go_plugin_get_dir_name (
-					plugin_service_get_plugin (service));
+					go_plugin_service_get_plugin (service));
 				char *tmp = g_build_filename (dir, path, NULL);
 				g_free (path);
 				path = tmp;
 			}
-			if (pending_reg_curve_type_files == NULL)
-				pending_reg_curve_type_files = g_hash_table_new_full (
-					g_str_hash, g_str_equal, g_free, g_object_unref);
-			g_object_ref (service);
-			g_hash_table_replace (pending_reg_curve_type_files, path, service);
+			paths = g_slist_append (paths, path);
 		}
+	GOG_TREND_LINE_SERVICE (service)->paths = paths;
+}
+
+static void
+gog_trend_line_service_activate (GOPluginService *service, GOErrorInfo **ret_error)
+{
+	GSList *l = GOG_TREND_LINE_SERVICE (service)->paths;
+	if (l && pending_trend_line_type_files == NULL)
+		pending_trend_line_type_files = g_hash_table_new_full (
+			g_str_hash, g_str_equal, g_free, g_object_unref);
+	while (l) {
+		g_object_ref (service);
+		g_hash_table_replace (pending_trend_line_type_files, l->data, service);
+		l = l->next;
+	}
+	service->is_active = TRUE;
+}
+
+static void
+gog_trend_line_service_deactivate (GOPluginService *service, GOErrorInfo **ret_error)
+{
+	GogTrendLineService *line_service = GOG_TREND_LINE_SERVICE (service);
+	GSList *l = line_service->types;
+	while (l) {
+		g_hash_table_remove (trend_line_types, ((GogTrendLineType *) l->data)->name);
+		l = l->next;
+	}
+	g_slist_free (line_service->types);
+	line_service->types = NULL;
+
+	if (pending_trend_line_type_files) {
+		l = line_service->paths;
+		while (l) {
+		    g_hash_table_remove (pending_trend_line_type_files, l->data);
+		    l = l->next;
+	    }
+	}
+	service->is_active = FALSE;
 }
 
 static char *
-gog_reg_curve_service_get_description (GOPluginService *service)
+gog_trend_line_service_get_description (GOPluginService *service)
 {
 	return g_strdup (_("Regression Curve Type"));
 }
 
+static void gog_trend_line_type_free (GogTrendLineType *type);
+
 static void
-gog_reg_curve_service_init (GObject *obj)
+gog_trend_line_service_finalize (GObject *obj)
 {
-	GogRegCurveService *service = GOG_REG_CURVE_SERVICE (obj);
+	GogTrendLineService *service = GOG_TREND_LINE_SERVICE (obj);
+	GSList *ptr;
+
+	for (ptr = service->types ; ptr != NULL ; ptr = ptr->next)
+		gog_trend_line_type_free ((GogTrendLineType *) ptr->data);
+	g_slist_free (service->types);
+	service->types = NULL;
+
+	g_slist_free (service->paths);
+	service->paths = NULL;
+
+	(plot_type_parent_klass->finalize) (obj);
+}
+
+static void
+gog_trend_line_service_init (GObject *obj)
+{
+	GogTrendLineService *service = GOG_TREND_LINE_SERVICE (obj);
 
 	service->types = NULL;
 }
 
 static void
-gog_reg_curve_service_class_init (GOPluginServiceClass *ps_class)
+gog_trend_line_service_class_init (GObjectClass *gobject_klass)
 {
-	ps_class->read_xml	  = gog_reg_curve_service_read_xml;
-	ps_class->get_description = gog_reg_curve_service_get_description;
+	GOPluginServiceClass *ps_class = GO_PLUGIN_SERVICE_CLASS (gobject_klass);
+
+	gobject_klass->finalize	  = gog_trend_line_service_finalize;
+	ps_class->read_xml	  = gog_trend_line_service_read_xml;
+	ps_class->get_description = gog_trend_line_service_get_description;
+	ps_class->activate	  = gog_trend_line_service_activate;
+	ps_class->deactivate	  = gog_trend_line_service_deactivate;
 }
 
-GSF_CLASS (GogRegCurveService, gog_reg_curve_service,
-           gog_reg_curve_service_class_init, gog_reg_curve_service_init,
-           GO_PLUGIN_SERVICE_SIMPLE_TYPE)
+GSF_CLASS (GogTrendLineService, gog_trend_line_service,
+           gog_trend_line_service_class_init, gog_trend_line_service_init,
+           GO_TYPE_PLUGIN_SERVICE_SIMPLE)
 
 /***************************************************************************/
 
 void
-gog_plugin_services_init (void)
+_gog_plugin_services_init (void)
 {
-	plugin_service_define ("plot_engine", &gog_plot_engine_service_get_type);
-	plugin_service_define ("plot_type",   &gog_plot_type_service_get_type);
-	plugin_service_define ("chart_theme",  &gog_theme_service_get_type);
-	plugin_service_define ("regcurve_engine", &gog_reg_curve_engine_service_get_type);
-	plugin_service_define ("regcurve_type", &gog_reg_curve_service_get_type);
+	go_plugin_service_define ("plot_engine", &gog_plot_engine_service_get_type);
+	go_plugin_service_define ("plot_type",   &gog_plot_type_service_get_type);
+	go_plugin_service_define ("chart_theme",  &gog_theme_service_get_type);
+	go_plugin_service_define ("trendline_engine", &gog_trend_line_engine_service_get_type);
+	go_plugin_service_define ("trendline_type", &gog_trend_line_service_get_type);
 }
 
 void
-gog_plugin_services_shutdown (void)
+_gog_plugin_services_shutdown (void)
 {
 	g_slist_foreach (refd_plugins, (GFunc)go_plugin_use_unref, NULL);
 	g_slist_foreach (refd_plugins, (GFunc)g_object_unref, NULL);
@@ -589,6 +701,10 @@ gog_plot_type_free (GogPlotType *type)
 	g_free (type->sample_image_file);
 	g_free (type->description);
 	g_free (type->engine);
+	if (type->properties) {
+		g_hash_table_destroy (type->properties);
+		type->properties = NULL;
+	}
 	g_free (type);
 }
 
@@ -642,15 +758,21 @@ gog_plot_family_register (char const *name, char const *sample_image_file,
 	return res;
 }
 
+void
+gog_plot_family_unregister (GogPlotFamily *family)
+{
+	g_hash_table_remove (plot_families, family->name);
+}
+
 GogPlotType *
 gog_plot_type_register (GogPlotFamily *family, int col, int row,
 		       char const *name, char const *sample_image_file,
 		       char const *description, char const *engine)
 {
 	GogPlotType *res;
-	
+
 	g_return_val_if_fail (family != NULL, NULL);
-	
+
 	res = g_new0 (GogPlotType, 1);
 	res->name = g_strdup (name);
 	res->sample_image_file = g_strdup (sample_image_file);
@@ -668,27 +790,31 @@ gog_plot_type_register (GogPlotFamily *family, int col, int row,
 /***************************************************************************/
 
 static void
-gog_reg_curve_type_free (GogRegCurveType *type)
+gog_trend_line_type_free (GogTrendLineType *type)
 {
 	g_free (type->name);
 	g_free (type->description);
 	g_free (type->engine);
 	g_free (type);
+	if (type->properties) {
+		g_hash_table_destroy (type->properties);
+		type->properties = NULL;
+	}
 }
 
 static void
-create_reg_curve_types (void)
+create_trend_line_types (void)
 {
-	if (!reg_curves_types)
-		reg_curves_types = g_hash_table_new_full
+	if (!trend_line_types)
+		trend_line_types = g_hash_table_new_full
 			(g_str_hash, g_str_equal,
-			 NULL, (GDestroyNotify) gog_reg_curve_type_free);
+			 NULL, (GDestroyNotify) gog_trend_line_type_free);
 }
 
 GHashTable const *
-gog_reg_curve_types (void)
+gog_trend_line_types (void)
 {
-	create_reg_curve_types ();
-	pending_reg_curves_types_load ();
-	return reg_curves_types;
+	create_trend_line_types ();
+	pending_trend_line_types_load ();
+	return trend_line_types;
 }
