@@ -230,7 +230,7 @@ select_row (GtkTreeView *list, int row)
 		path = gtk_tree_path_new_from_indices (row, -1);
 
 		gtk_tree_selection_select_path (gtk_tree_view_get_selection (list), path);
-		if (gtk_widget_is_realized (list))
+		if (gtk_widget_get_realized (GTK_WIDGET (list)))
 			cb_list_adjust (list);
 		gtk_tree_path_free (path);
 	}
