@@ -22,7 +22,7 @@
 #ifndef GO_GEOMETRY_H
 #define GO_GEOMETRY_H
 
-#include <goffice/graph/goffice-graph.h>
+#include <goffice/goffice.h>
 
 G_BEGIN_DECLS
 
@@ -38,11 +38,19 @@ typedef enum {
 	GO_SIDE_AUTO		= 15
 } GOGeometrySide;
 
+typedef enum {
+	GO_DIRECTION_UP    = 0,
+	GO_DIRECTION_DOWN  = 1,
+	GO_DIRECTION_LEFT  = 2,
+	GO_DIRECTION_RIGHT = 3,
+	GO_DIRECTION_NONE  = 4
+} GODirection;
+
 typedef enum {
 	GO_ROTATE_NONE = 0,
 	GO_ROTATE_COUNTERCLOCKWISE = 1,
 	GO_ROTATE_UPSIDEDOWN = 2,
-	GO_ROTATE_CLOCKWISE = 3,	
+	GO_ROTATE_CLOCKWISE = 3,
 	GO_ROTATE_FREE = 4
 } GOGeometryRotationType;
 
@@ -52,7 +60,7 @@ typedef struct {
         double alpha;   /* Angle from x axis to w edge, in radians */
 } GOGeometryOBR;
 
-#define GOGeometryAABR GogViewAllocation /* x, y: top left corner */
+typedef struct _GogViewAllocation GOGeometryAABR;
 
 void 		go_geometry_cartesian_to_polar 	(double x, double y, double *rho, double *theta);
 double 		go_geometry_point_to_segment	(double xp, double yp, double xs, double ys, double w, double h);
@@ -66,6 +74,11 @@ GOGeometrySide 		go_geometry_calc_label_anchor 	(GOGeometryOBR *obr, double alph
 GOGeometrySide		go_geometry_calc_label_position	(GOGeometryOBR *obr, double alpha, double offset,
 							 GOGeometrySide side, GOGeometrySide anchor);
 
+#define  GO_TYPE_DIRECTION (go_direction_get_type())
+GType    go_direction_get_type	    (void) G_GNUC_CONST;
+gboolean go_direction_is_horizontal (GODirection d);
+gboolean go_direction_is_forward    (GODirection d);
+
 G_END_DECLS
 
 #endif /* GO_GEOMETRY_H */
